VLC command-line help: Difference between revisions

From VideoLAN Wiki
Jump to navigation Jump to search
add --help-verbose
Update
Line 3: Line 3:
If you look for help, on a particular module, use ''vlc -p module --advanced''
If you look for help, on a particular module, use ''vlc -p module --advanced''


So here the output of ''vlc --longhelp --advanced'' as of 2nd February 2005 for the development version.
So here the output of ''vlc --longhelp --advanced'' as of 7th April 2005 for the development version.


If you want extra explanations, you can try the ''--help-verbose '' option.
If you want extra explanations, you can try the ''--help-verbose '' option.
[[Help verbose]]




  <nowiki>    --audio, --noaudio        Enable audio (default enabled)
  <nowiki>     
Usage: c:\...\vlc-0.8.2-svn-20050407\vlc.exe [options] [playlistitems] ...
You can specify multiple playlistitems on the commandline. They will be enqueued in the playlist.
The first item specified will be played first.
 
Options-styles:
  --option  A global option that is set for the duration of the program.
  -option  A single letter version of a global --option.
  :option  An option that only applies to the playlistitem directly before it
            and that overrides previous settings.
 
Playlistitem MRL syntax:
  URL[@[title][:chapter][-[title][:chapter]]] [:option=value ...]
 
  Many of the global --options can also be used as MRL specific :options.
  Multiple :option=value pairs can be specified.
 
URL syntax:
  [file://]filename              Plain media file
  http://ip:port/file            HTTP URL
  ftp://ip:port/file            FTP URL
  mms://ip:port/file            MMS URL
  screen://                      Screen capture
  [dvd://][device][@raw_device]  DVD device
  [vcd://][device]              VCD device
  [cdda://][device]              Audio CD device
  udp:[[<source address>]@[<bind address>][:<bind port>]]
                                UDP stream sent by a streaming server
  vlc:pause                      Special item to pause the playlist
  vlc:quit                      Special item to quit VLC
 
Audio
      --audio, --noaudio        Enable audio (default enabled)
       --volume <integer>        Audio output volume
       --volume <integer>        Audio output volume
      --saved-volume <integer>  Audio output saved volume
       --aout-rate <integer>      Audio output frequency (Hz)
       --aout-rate <integer>      Audio output frequency (Hz)
       --hq-resampling, --no-hq-resampling
       --hq-resampling, --no-hq-resampling
Line 17: Line 49:
       --spdif, --nospdif        Use the S/PDIF audio output when available
       --spdif, --nospdif        Use the S/PDIF audio output when available
                                 (default disabled)
                                 (default disabled)
       --audio-desync <integer>  Audio desynchronization compensation
       --audio-desync <integer>  Audio desynchronisation compensation
       --aout <string>            Audio output module
       --aout <string>            Audio output module
       --audio-filter <string>    Audio filters
       --audio-filter <string>    Audio filters
       --audio-visual <string>    Audio visualizations
       --audio-visual <string>    Audio visualizations  
  -A, --audio-channel-mixer <string>
 
                                Channel mixer
Video
       --video, --novideo        Enable video (default enabled)
       --video, --novideo        Enable video (default enabled)
      --width <integer>          Video width
       --grayscale, --nograyscale Greyscale video output (default disabled)
      --height <integer>        Video height
      --video-x <integer>        Video x coordinate
      --video-y <integer>        Video y coordinate
      --video-deco, --no-video-deco
                                Window decorations (default enabled)
      --video-title <string>    Video title
      --align <integer>          Video alignment
      --zoom <float>            Zoom video
       --grayscale, --nograyscale Grayscale video output (default disabled)
   -f, --fullscreen, --nofullscreen
   -f, --fullscreen, --nofullscreen
                                 Fullscreen video output (default disabled)
                                 Fullscreen video output (default disabled)
       --skip-frames, --no-skip-frames
       --skip-frames, --no-skip-frames
                                 Skip frames (default enabled)
                                 Skip frames (default enabled)
      --quiet-synchro, --no-quiet-synchro
                                Quiet synchro (default disabled)
       --overlay, --nooverlay    Overlay video output (default enabled)
       --overlay, --nooverlay    Overlay video output (default enabled)
       --video-on-top, --no-video-on-top
       --video-on-top, --no-video-on-top
                                 Always on top (default disabled)
                                 Always on top (default disabled)
      --aspect-ratio <string>    Source aspect ratio
       --snapshot-path <string>  Video snapshot directory
       --snapshot-path <string>  Video snapshot directory
       --snapshot-format {png,jpg}
       --snapshot-format {png,jpg}
                                 Video snapshot format
                                 Video snapshot format
      --width <integer>          Video width
      --height <integer>        Video height
      --video-x <integer>        Video x coordinate
      --video-y <integer>        Video y coordinate
      --aspect-ratio <string>    Source aspect ratio
      --video-deco, --no-video-deco
                                Window decorations (default enabled)
      --video-title <string>    Video title
      --align {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                Video alignment
      --zoom <float>            Zoom video
   -V, --vout <string>            Video output module
   -V, --vout <string>            Video output module
       --filter <string>         Video filter module
       --vout-filter <string>     Video filter module
 
Subpictures
       --osd, --noosd            On Screen Display (default enabled)
       --osd, --noosd            On Screen Display (default enabled)
      --sub-file <string>        Use subtitle file
       --sub-autodetect-file, --no-sub-autodetect-file
       --sub-autodetect-file, --no-sub-autodetect-file
                                 Autodetect subtitle files (default enabled)
                                 Autodetect subtitle files (default enabled)
Line 54: Line 92:
       --sub-autodetect-path <string>
       --sub-autodetect-path <string>
                                 Subtitle autodetection paths
                                 Subtitle autodetection paths
       --sub-file <string>        Use subtitle file
       --sub-margin <integer>     Force subtitle position
      --spumargin <integer>     Force SPU position
       --sub-filter <string>      Subpictures filter module
       --sub-filter <string>      Subpictures filter module
       --program <integer>        Choose program (SID)
 
Input
      --access <string>          Access module
      --access-filter <string>  Access filter module
      --demux <string>          Demux module
       --program <integer>        Choose programme (SID)
       --programs <string>        Choose programs
       --programs <string>        Choose programs
       --audio-channel <integer> Choose audio channel
       --audio-track <integer>   Choose audio track
       --spu-channel <integer>   Choose subtitles track
       --sub-track <integer>     Choose subtitles track
      --audio-language <string>  Choose audio language
      --sub-language <string>    Choose subtitle language
       --input-repeat <integer>  Input repetitions
       --input-repeat <integer>  Input repetitions
       --start-time <integer>    Input start time (seconds)
       --start-time <integer>    Input start time (seconds)
Line 88: Line 132:
       --meta-url <string>        URL metadata
       --meta-url <string>        URL metadata
       --cr-average <integer>    Clock reference average counter
       --cr-average <integer>    Clock reference average counter
      --clock-synchro {-1 (Default), 0 (Disable), 1 (Enable)}
                                Clock synchronisation


  Decoders
  Decoders
Line 94: Line 140:


  Stream output
  Stream output
       --sout <string>            Choose a stream output
       --sout <string>            Default stream output chain
       --sout-display, --no-sout-display
       --sout-display, --no-sout-display
                                 Display while streaming (default disabled)
                                 Display while streaming (default disabled)
Line 107: Line 153:
       --mux <string>            Mux module
       --mux <string>            Mux module
       --access_output <string>  Access output module
       --access_output <string>  Access output module
       --packetizer <string>      Preferred packetizer list
       --packetizer <string>      Preferred packetiser list
       --sap-flow-control, --no-sap-flow-control
       --sap-flow-control, --no-sap-flow-control
                                 Control SAP flow (default disabled)
                                 Control SAP flow (default disabled)
       --sap-interval <integer>  SAP announcement interval
       --sap-interval <integer>  SAP announcement interval
CPU
      --fpu, --nofpu            Enable FPU support (default enabled)
       --mmx, --nommx            Enable CPU MMX support (default enabled)
       --mmx, --nommx            Enable CPU MMX support (default enabled)
       --3dn, --no3dn            Enable CPU 3D Now! support (default enabled)
       --3dn, --no3dn            Enable CPU 3D Now! support (default enabled)
Line 116: Line 165:
       --sse, --nosse            Enable CPU SSE support (default enabled)
       --sse, --nosse            Enable CPU SSE support (default enabled)
       --sse2, --nosse2          Enable CPU SSE2 support (default enabled)
       --sse2, --nosse2          Enable CPU SSE2 support (default enabled)
Miscellaneous
       --memcpy <string>          Memory copy module
       --memcpy <string>          Memory copy module
      --access <string>          Access module
  -A, --audio-channel-mixer <string>
      --demux <string>           Demux module
                                 Channel mixer
      --minimize-threads, --no-minimize-threads
                                 Minimize number of threads (default disabled)
       --plugins-cache, --no-plugins-cache
       --plugins-cache, --no-plugins-cache
                                 Use a plugins cache (default enabled)
                                 Use a plugins cache (default enabled)
       --plugin-path <string>    Modules search path
       --plugin-path <string>    Modules search path
       --vlm-conf <string>        VLM configuration file
       --minimize-threads, --no-minimize-threads
                                Minimise number of threads (default disabled)
       --one-instance, --no-one-instance
       --one-instance, --no-one-instance
                                 Allow only one running instance (default
                                 Allow only one running instance (default
Line 137: Line 187:
                                 Condition variables implementation for Win9x
                                 Condition variables implementation for Win9x
                                 (developers only)
                                 (developers only)
      --vlm-conf <string>        VLM configuration file


  Playlist
  Playlist
   -Z, --random, --norandom      Play files randomly forever (default disabled)
   -Z, --random, --norandom      Play files randomly forever (default enabled)
   -L, --loop, --noloop          Loop playlist on end (default disabled)
   -L, --loop, --noloop          Repeat all (default enabled)
   -R, --repeat, --norepeat      Repeat the current item (default disabled)
   -R, --repeat, --norepeat      Repeat current item (default disabled)
       --play-and-stop, --no-play-and-stop
       --play-and-stop, --no-play-and-stop
                                 Play and stop (default disabled)
                                 Play and stop (default disabled)
   -S, --services-discovery <string>
   -S, --services-discovery <string>
                                 Services discovery modules
                                 Services discovery modules
Interface
   -I, --intf <string>            Interface module
   -I, --intf <string>            Interface module
       --extraintf <string>      Extra interface modules
       --extraintf <string>      Extra interface modules
   -v, --verbose <integer>        Verbosity (0,1,2)
   -v, --verbose <integer>        Verbosity (0,1,2)
   -q, --quiet, --noquiet        Be quiet (default disabled)
   -q, --quiet, --noquiet        Be quiet (default disabled)
       --language {auto,en,en_GB,es,de,fr,hu,it,ja,nl,no,pl,pt_BR,ru,sv}
       --language {auto,en,en_GB,bn,da,de,el,es,fr,hi,hu,it,ja,my,ne,nl,no,pl,ps,pt_BR,ru,sv,tet,tl}
                                 Language
                                 Language
       --color, --nocolor        Color messages (default disabled)
       --color, --nocolor        Colour messages (default disabled)
       --advanced, --noadvanced  Show advanced options (default enabled)
       --advanced, --noadvanced  Show advanced options (default enabled)
       --control <string>        Control interfaces
       --control <string>        Control interfaces
Line 241: Line 294:
       --key-history-forward <integer>
       --key-history-forward <integer>
                                 Go forward in browsing history
                                 Go forward in browsing history
Playlist MRL syntax:
  URL[@[title][:chapter][-[title][:chapter]]] [:option=value]
URL syntax:
  [file://]filename              plain media file
  http://ip:port/file            HTTP URL
  ftp://ip:port/file            FTP URL
  mms://ip:port/file            MMS URL
  screen://                      Screen capture
  [dvd://][device][@raw_device]  DVD device
  [vcd://][device]              VCD device
  [cdda://][device]              Audio CD device
  udp:[[<source address>]@[<bind address>][:<bind port>]]
                                UDP stream sent by a streaming server
  vlc:pause                      pause execution of playlist items
  vlc:quit                      quit VLC


  Help options
  Help options
   -h, --help                    print help (can be combined with --advanced)
   -h, --help                    print help for VLC (can be combined with
  -H, --longhelp                print detailed help (can be combined with
                                 --advanced)
                                 --advanced)
  -H, --longhelp                print help for VLC and all it's modules (can
                                be combined with --advanced)
      --advanced                print help for the advanced options
      --help-verbose            ask for extra verbosity when displaying help
   -l, --list                    print a list of available modules
   -l, --list                    print a list of available modules
   -p, --module <string>          print help on module (can be combined with
   -p, --module <string>          print help on a specific module (can be
                                --advanced)
                                combined with --advanced)
       --save-config              save the current command line options in the
       --save-config              save the current command line options in the
                                 config
                                 config
Line 279: Line 317:
       --rtsp-kasenna, --no-rtsp-kasenna
       --rtsp-kasenna, --no-rtsp-kasenna
                                 Kasenna RTSP dialect (default disabled)
                                 Kasenna RTSP dialect (default disabled)
TS muxer (libdvbpsi)
      --sout-ts-pid-video <integer>
                                Video PID
      --sout-ts-pid-audio <integer>
                                Audio PID
      --sout-ts-pid-spu <integer>
                                SPU PID
      --sout-ts-pid-pmt <integer>
                                PMT PID
      --sout-ts-tsid <integer>  TS ID
      --sout-ts-es-id-pid, --no-sout-ts-es-id-pid
                                Set PID to id of ES (default disabled)
      --sout-ts-shaping <integer>
                                Shaping delay (ms)
      --sout-ts-use-key-frames, --no-sout-ts-use-key-frames
                                Use keyframes (default disabled)
      --sout-ts-pcr <integer>    PCR delay (ms)
      --sout-ts-bmin <integer>  Minimum B (deprecated)
      --sout-ts-bmax <integer>  Maximum B (deprecated)
      --sout-ts-dts-delay <integer>
                                DTS delay (ms)
      --sout-ts-crypt-audio, --no-sout-ts-crypt-audio
                                Crypt audio (default enabled)
      --sout-ts-csa-ck <string>  CSA Key


  Matroska stream demuxer
  Matroska stream demuxer
      --mkv-use-ordered-chapters, --no-mkv-use-ordered-chapters
                                Ordered chapters (default enabled)
      --mkv-use-chapter-codec, --no-mkv-use-chapter-codec
                                Chapter codecs (default enabled)
       --mkv-seek-percent, --no-mkv-seek-percent
       --mkv-seek-percent, --no-mkv-seek-percent
                                 Seek based on percent not time (default
                                 Seek based on percent not time (default
                                 enabled)
                                 disabled)
      --mkv-use-dummy, --no-mkv-use-dummy
                                Dummy Elements (default disabled)


  ffmpeg audio/video decoder ((MS)MPEG4,SVQ1,H263,WMV,WMA)
  Ffmpeg audio/video decoder/encoder ((MS)MPEG4,SVQ1,H263,WMV,WMA)
       --ffmpeg-dr, --no-ffmpeg-dr
       --ffmpeg-dr, --no-ffmpeg-dr
                                 Direct rendering (default enabled)
                                 Direct rendering (default enabled)
Line 294: Line 363:
       --ffmpeg-hurry-up, --no-ffmpeg-hurry-up
       --ffmpeg-hurry-up, --no-ffmpeg-hurry-up
                                 Hurry up (default disabled)
                                 Hurry up (default disabled)
       --ffmpeg-vismv <integer>  Visualize motion vectors
       --ffmpeg-vismv <integer>  Visualise motion vectors
       --ffmpeg-lowres <integer>  Low resolution decoding
       --ffmpeg-lowres <integer>  Low resolution decoding
       --ffmpeg-pp-q <integer>    Post processing quality
       --ffmpeg-pp-q <integer>    Post processing quality
Line 320: Line 389:
                                 Rate control buffer aggressiveness
                                 Rate control buffer aggressiveness
       --sout-ffmpeg-i-quant-factor <float>
       --sout-ffmpeg-i-quant-factor <float>
                                 I quantization factor
                                 I quantisation factor
       --sout-ffmpeg-noise-reduction <integer>
       --sout-ffmpeg-noise-reduction <integer>
                                 Noise reduction
                                 Noise reduction
       --sout-ffmpeg-mpeg4-matrix, --no-sout-ffmpeg-mpeg4-matrix
       --sout-ffmpeg-mpeg4-matrix, --no-sout-ffmpeg-mpeg4-matrix
                                 Enable MPEG4 quantization matrix (default
                                 Enable MPEG4 quantisation matrix (default
                                 disabled)
                                 disabled)
       --sout-ffmpeg-qmin <integer>
       --sout-ffmpeg-qmin <integer>
                                 Minimum video quantizer scale
                                 Minimum video quantiser scale
       --sout-ffmpeg-qmax <integer>
       --sout-ffmpeg-qmax <integer>
                                 Maximum video quantizer scale
                                 Maximum video quantiser scale
       --sout-ffmpeg-trellis, --no-sout-ffmpeg-trellis
       --sout-ffmpeg-trellis, --no-sout-ffmpeg-trellis
                                 Enable trellis quantization (default disabled)
                                 Enable trellis quantisation (default disabled)
       --sout-ffmpeg-qscale <float>
       --sout-ffmpeg-qscale <float>
                                 Use fixed video quantizer scale
                                 Use fixed video quantizer scale
       --sout-ffmpeg-strict <integer>
       --sout-ffmpeg-strict <integer>
                                 Strict standard compliance
                                 Strict standard compliance
MPEG2 video switcher stream output
      --sout-switcher-files <string>
                                Files
      --sout-switcher-sizes <string>
                                Sizes
      --sout-switcher-aspect-ratio <string>
                                Aspect ratio
      --sout-switcher-port <integer>
                                Command UDP port
      --sout-switcher-command <integer>
                                Command
      --sout-switcher-gop <integer>
                                GOP size
      --sout-switcher-qscale <integer>
                                Quantizer scale


  ATSC A/52 (AC-3) audio decoder
  ATSC A/52 (AC-3) audio decoder
Line 344: Line 429:
  Standard filesystem directory input
  Standard filesystem directory input
       --recursive {none,collapse,expand}
       --recursive {none,collapse,expand}
                                 Subdirectory behavior
                                 Subdirectory behaviour
 
Fake input
      --fake-caching <integer>  Caching value in ms
      --fake-fps <float>        Framerate


  Standard filesystem file input
  Standard filesystem file input
Line 394: Line 483:
       --sout-udp-raw, --no-sout-udp-raw
       --sout-udp-raw, --no-sout-udp-raw
                                 Raw write (default disabled)
                                 Raw write (default disabled)
SMB input
      --smb-caching <integer>    Caching value in ms
      --smb-user <string>        SMB user name
      --smb-pwd <string>        SMB password
      --smb-domain <string>      SMB domain


  TCP input
  TCP input
Line 411: Line 506:


  File audio output
  File audio output
       --audiofile-format {u8,s8,u16,s16,u16_le,s16_le,u16_be,s16_be,fixed32,floa
       --audiofile-format {u8,s8,u16,s16,u16_le,s16_le,u16_be,s16_be,fixed32,float32,spdif}
t32,spdif}
                                 Output format
                                 Output format
       --audiofile-channels <integer>
       --audiofile-channels <integer>
Line 449: Line 543:
       --distort-mode {wave,ripple}
       --distort-mode {wave,ripple}
                                 Distort mode
                                 Distort mode
DTS Coherent Acoustics audio decoder
      --dts-dynrng, --no-dts-dynrng
                                DTS dynamic range compression (default
                                enabled)


  Dummy interface function
  Dummy interface function
Line 477: Line 566:


  Equalizer 10 bands
  Equalizer 10 bands
       --equalizer-preset {flat,classical,club,dance,fullbass,fullbasstreble,full
       --equalizer-preset {flat,classical,club,dance,fullbass,fullbasstreble,fulltreble,headphones,largehall,live,party,pop,reggae,rock,ska,soft,softrock,techno}
treble,headphones,largehall,live,party,pop,reggae,rock,ska,soft,softrock,techno}
 
                                 Equalizer preset
                                 Equalizer preset
       --equalizer-bands <string> Bands gain
       --equalizer-bands <string> Bands gain
Line 486: Line 573:
       --equalizer-preamp <float> Global gain
       --equalizer-preamp <float> Global gain


  freetype2 font renderer
  Freetype2 font renderer
       --freetype-font <string>  Font
       --freetype-font <string>  Font
       --freetype-fontsize <integer>
       --freetype-fontsize <integer>
                                 Font size in pixels
                                 Font size in pixels
       --freetype-rel-fontsize <integer>
      --freetype-opacity <integer>
                                Opacity, 0..255
      --freetype-color {0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                Text Default Color
       --freetype-rel-fontsize {20 (Smaller), 18 (Small), 16 (Normal), 12 (Large), 6 (Larger)}
                                 Font size
                                 Font size


Line 498: Line 589:
       --gestures-button {left,middle,right}
       --gestures-button {left,middle,right}
                                 Trigger button
                                 Trigger button
GnuTLS TLS encryption layer
      --dh-bits <integer>        Diffie-Hellman prime bits
      --tls-cache-expiration <integer>
                                Expiration time for resumed TLS sessions
      --tls-cache-size <integer> Number of resumed TLS sessions


  Goom effect
  Goom effect
Line 505: Line 602:


  H264 video demuxer
  H264 video demuxer
       --h264-fps <float>        fps
       --h264-fps <float>        Frames per Second


  headphone channel mixer with virtual spatialization effect
  Headphone channel mixer with virtual spatialization effect
       --headphone-dim <integer>  Characteristic dimension
       --headphone-dim <integer>  Characteristic dimension


Line 550: Line 647:
       --logo-transparency <integer>
       --logo-transparency <integer>
                                 Transparency of the logo
                                 Transparency of the logo
       --logo-position <integer>  Logo position
       --logo-position {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                Logo position


  Marquee display sub filter
  Marquee display sub filter
Line 556: Line 654:
       --marq-x <integer>        X offset, from left
       --marq-x <integer>        X offset, from left
       --marq-y <integer>        Y offset, from the top
       --marq-y <integer>        Y offset, from the top
      --marq-position <integer>  Marquee position
      --marq-opacity <integer>  Opacity
      --marq-color {-268435456 (Default), 0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                Text Default Color
      --marq-size <integer>      Font size, pixels
       --marq-timeout <integer>  Marquee timeout
       --marq-timeout <integer>  Marquee timeout


Line 582: Line 685:
       --mod-surround-delay <integer>
       --mod-surround-delay <integer>
                                 Surround delay (ms)
                                 Surround delay (ms)
Mosaic video sub filter
      --mosaic-alpha <integer>  Alpha blending
      --mosaic-height <integer>  Height in pixels
      --mosaic-width <integer>  Width in pixels
      --mosaic-align {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                Mosaic alignment
      --mosaic-xoffset <integer> Top left corner x coordinate
      --mosaic-yoffset <integer> Top left corner y coordinate
      --mosaic-vborder <integer> Vertical border width in pixels
      --mosaic-hborder <integer> Horizontal border width in pixels
      --mosaic-position {0 (auto), 1 (fixed)}
                                Positioning method
      --mosaic-rows <integer>    Number of rows
      --mosaic-cols <integer>    Number of columns
      --mosaic-keep-aspect-ratio, --no-mosaic-keep-aspect-ratio
                                Keep aspect ratio when resizing (default
                                disabled)
      --mosaic-keep-picture, --no-mosaic-keep-picture
                                Keep original size (default disabled)
      --mosaic-order <string>    Order as a comma separated list of
                                picture-id(s)
      --mosaic-delay <integer>  Delay


  Motion blur filter
  Motion blur filter
Line 600: Line 726:
                                 Comment
                                 Comment
       --sout-asf-rating <string> Rating
       --sout-asf-rating <string> Rating
      --sout-asf-packet-size <integer>
                                Packet Size


  MP4/MOV muxer
  MP4/MOV muxer
       --sout-mp4-faststart, --no-sout-mp4-faststart
       --sout-mp4-faststart, --no-sout-mp4-faststart
                                 Create "Fast start" files (default enabled)
                                 Create "Fast start" files (default enabled)
Multipart jpeg muxer
      --sout-mpjpeg-separator <string>
                                Multipart separator string


  PS muxer
  PS muxer
       --sout-ps-dts-delay <integer>
       --sout-ps-dts-delay <integer>
                                 DTS delay (ms)
                                 DTS delay (ms)
TS muxer (libdvbpsi)
      --sout-ts-pid-video <integer>
                                Video PID
      --sout-ts-pid-audio <integer>
                                Audio PID
      --sout-ts-pid-spu <integer>
                                SPU PID
      --sout-ts-pid-pmt <integer>
                                PMT PID
      --sout-ts-tsid <integer>  TS ID
      --sout-ts-shaping <integer>
                                Shaping delay (ms)
      --sout-ts-use-key-frames, --no-sout-ts-use-key-frames
                                Use keyframes (default disabled)
      --sout-ts-pcr <integer>    PCR delay (ms)
      --sout-ts-bmin <integer>  Minimum B (deprecated)
      --sout-ts-bmax <integer>  Maximum B (deprecated)
      --sout-ts-dts-delay <integer>
                                DTS delay (ms)
      --sout-ts-crypt-audio, --no-sout-ts-crypt-audio
                                Crypt audio (default enabled)
      --sout-ts-csa-ck <string>  CSA Key


  Network synchronisation
  Network synchronisation
Line 659: Line 768:
       --opengl-effect {none,cube,transparent-cube}
       --opengl-effect {none,cube,transparent-cube}
                                 Select effect
                                 Select effect
VLC internal picture video output
      --picture-id <string>      ID
      --picture-width <integer>  Video width
      --picture-height <integer> Video height
PORTAUDIO audio output
      --portaudio-device <integer>
                                Output device


  Remote control interface
  Remote control interface
Line 669: Line 787:
       --rc-quiet, --no-rc-quiet  Do not open a DOS command box interface
       --rc-quiet, --no-rc-quiet  Do not open a DOS command box interface
                                 (default disabled)
                                 (default disabled)
      --rc-extend, --no-rc-extend
                                Extended help (default disabled)


  SAP interface
  SAP announces
       --sap-addr <string>        SAP multicast address
       --sap-addr <string>        SAP multicast address
       --sap-ipv4, --no-sap-ipv4  IPv4-SAP listening (default enabled)
       --sap-ipv4, --no-sap-ipv4  IPv4-SAP listening (default enabled)
Line 694: Line 810:
       --showintf-threshold <integer>
       --showintf-threshold <integer>
                                 Threshold
                                 Threshold
Skinnable Interface
      --skins2-last <string>    Last skin used
      --skins2-config <string>  Config of last used skin
      --skins2-transparency, --no-skins2-transparency
                                Enable transparency effects (default disabled)
stream_out_bridge
      --sout-bridge-out-id <integer>
                                ID
      --sout-bridge-in-delay <integer>
                                Delay
      --sout-bridge-in-id-offset <integer>
                                ID Offset


  Display stream output
  Display stream output
Line 789: Line 919:
       --sout-transcode-samplerate <integer>
       --sout-transcode-samplerate <integer>
                                 Audio sample rate
                                 Audio sample rate
      --sout-transcode-audio-sync, --no-sout-transcode-audio-sync
                                Synchronise on audio track (default disabled)
       --sout-transcode-senc <string>
       --sout-transcode-senc <string>
                                 Subtitles encoder
                                 Subtitles encoder
Line 799: Line 931:
       --sout-transcode-threads <integer>
       --sout-transcode-threads <integer>
                                 Number of threads
                                 Number of threads
      --sout-transcode-audio-sync, --no-sout-transcode-audio-sync
                                Synchronise on audio track (default disabled)


  text subtitles decoder
  Text subtitles decoder
       --subsdec-align <integer>  Subtitles justification
       --subsdec-align {0 (Center), 1 (Left), 2 (Right)}
       --subsdec-encoding {System Default,ASCII,UTF-8,,ISO-8859-1,CP1252,MacRoman
                                Subtitles justification
,MacIceland,ISO-8859-15,,ISO-8859-2,CP1250,MacCentralEurope,MacCroatian,MacRoman
       --subsdec-encoding {System Default,ASCII,UTF-8,,ISO-8859-1,CP1252,MacRoman,MacIceland,ISO-8859-15,,ISO-8859-2,CP1250,MacCentralEurope,MacCroatian,MacRomania,,ISO-8859-5,CP1251,MacCyrillic,MacUkraine,KOI8-R,KOI8-U,KOI8-RU,,ISO-8859-6,CP1256,MacArabic,,ISO-8859-7,CP1253,MacGreek,,ISO-8859-8,CP1255,MacHebrew,,ISO-8859-9,CP1254,MacTurkish,,ISO-8859-13,CP1257,,ISO-2022-JP,ISO-2022-JP-1,ISO-2022-JP-2,EUC-JP,SHIFT_JIS,,ISO-2022-CN,ISO-2022-CN-EXT,EUC-CN,EUC-TW,BIG5,BIG5-HKSCS,,ISO-2022-KR,EUC-KR,,MacThai,KOI8-T,,ISO-8859-3,ISO-8859-4,ISO-8859-10,ISO-8859-14,ISO-8859-16,,CP850,CP862,CP866,CP874,CP932,CP949,CP950,CP1133,CP1258,,Macintosh,,UTF-7,UTF-16,UTF-16BE,UTF-16LE,UTF-32,UTF-32BE,UTF-32LE,C99,JAVA,UCS-2,UCS-2BE,UCS-2LE,UCS-4,UCS-4BE,UCS-4LE,,HZ,GBK,GB18030,JOHAB,ARMSCII-8,Georgian-Academy,Georgian-PS,TIS-620,MuleLao-1,VISCII,TCVN,HPROMAN8,NEXTSTEP}
ia,,ISO-8859-5,CP1251,MacCyrillic,MacUkraine,KOI8-R,KOI8-U,KOI8-RU,,ISO-8859-6,C
P1256,MacArabic,,ISO-8859-7,CP1253,MacGreek,,ISO-8859-8,CP1255,MacHebrew,,ISO-88
59-9,CP1254,MacTurkish,,ISO-8859-13,CP1257,,ISO-2022-JP,ISO-2022-JP-1,ISO-2022-J
P-2,EUC-JP,SHIFT_JIS,,ISO-2022-CN,ISO-2022-CN-EXT,EUC-CN,EUC-TW,BIG5,BIG5-HKSCS,
,ISO-2022-KR,EUC-KR,,MacThai,KOI8-T,,ISO-8859-3,ISO-8859-4,ISO-8859-10,ISO-8859-
14,ISO-8859-16,,CP850,CP862,CP866,CP874,CP932,CP949,CP950,CP1133,CP1258,,Macinto
sh,,UTF-7,UTF-16,UTF-16BE,UTF-16LE,UTF-32,UTF-32BE,UTF-32LE,C99,JAVA,UCS-2,UCS-2
BE,UCS-2LE,UCS-4,UCS-4BE,UCS-4LE,,HZ,GBK,GB18030,JOHAB,ARMSCII-8,Georgian-Academ
y,Georgian-PS,TIS-620,MuleLao-1,VISCII,TCVN,HPROMAN8,NEXTSTEP}
                                 Subtitles text encoding
                                 Subtitles text encoding


Line 823: Line 944:
                                 Subtitles fileformat
                                 Subtitles fileformat


  Telnet remote control interface
  Philips OGT (SVCD subtitle) decoder
      --svcdsub-debug <integer>  If nonzero, this gives additional debug
                                information.
 
VLM remote control interface
       --telnet-port <integer>    Telnet Interface port
       --telnet-port <integer>    Telnet Interface port
       --telnet-password <string> Telnet Interface password
       --telnet-password <string> Telnet Interface password
Line 835: Line 960:
       --time-x <integer>        X offset, from left
       --time-x <integer>        X offset, from left
       --time-y <integer>        Y offset, from the top
       --time-y <integer>        Y offset, from the top
      --time-position {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                Time position
      --time-opacity <integer>  Opacity, 0..255
      --time-color {-268435456 (Default), 0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                Text Default Color
      --time-size <integer>      Font size, pixels


  libtoolame audio encoder
  Libtoolame audio encoder
       --sout-toolame-quality <float>
       --sout-toolame-quality <float>
                                 Encoding quality
                                 Encoding quality
Line 848: Line 979:
                                 Transform type
                                 Transform type


  ISO 13818-1 MPEG Transport Stream input - new
  MPEG Transport Stream demuxer
       --ts-extra-pmt <string>    Extra PMT
       --ts-extra-pmt <string>    Extra PMT
       --ts-es-id-pid, --no-ts-es-id-pid
       --ts-es-id-pid, --no-ts-es-id-pid
Line 886: Line 1,017:
                                 CBR encoding (default disabled)
                                 CBR encoding (default disabled)


  wall video filter
  Wall video filter
       --wall-cols <integer>      Number of columns
       --wall-cols <integer>      Number of columns
       --wall-rows <integer>      Number of rows
       --wall-rows <integer>      Number of rows
       --wall-active <string>    Active windows
       --wall-active <string>    Active windows
      --wall-element-aspect <string>
                                Element aspect ratio


  Win32 waveOut extension output
  Win32 waveOut extension output
Line 899: Line 1,032:
                                 Embed video in interface (default enabled)
                                 Embed video in interface (default enabled)
       --wxwin-bookmarks, --no-wxwin-bookmarks
       --wxwin-bookmarks, --no-wxwin-bookmarks
                                 Show bookmarks dialog (default disabled)
                                 Show bookmarks dialogue (default disabled)
 
       --wxwin-taskbar, --no-wxwin-taskbar
h264 video encoder using x264 library
                                 Show taskbar entry (default enabled)
      --sout-x264-qp <integer>  Quantizer parameter
       --wxwin-systray, --no-wxwin-systray
      --sout-x264-qp-min <integer>
                                 Show systray icon (default disabled)
                                Minimum quantizer parameter
       --wxwin-config-last <string>
       --sout-x264-qp-max <integer>
                                 last config
                                Maximum quantizer parameter
      --sout-x264-cabac, --no-sout-x264-cabac
                                 Enable CABAC (default enabled)
       --sout-x264-loopfilter, --no-sout-x264-loopfilter
                                 Enable loop filter (default enabled)
       --sout-x264-analyse {,all,normal,fast,none}
                                Analyse mode
      --sout-x264-keyint <integer>
                                Sets maximum interval between IDR-frames
      --sout-x264-keyint-min <integer>
                                 Sets minimum interval between IDR-frames
      --sout-x264-bframes <integer>
                                B frames
      --sout-x264-frameref <integer>
                                Number of previous frames used as predictors.
      --sout-x264-scenecut <integer>
                                Scene-cut detection.


  DirectShow input
  DirectShow input
Line 938: Line 1,054:
       --dshow-tuner-country <integer>
       --dshow-tuner-country <integer>
                                 Tuner country code
                                 Tuner country code
       --dshow-tuner-input <integer>
       --dshow-tuner-input {0 (Default), 1 (Cable), 2 (Antenna)}
                                 Tuner input type
                                 Tuner input type


Line 953: Line 1,069:
       --directx-device {}        Name of desired display device
       --directx-device {}        Name of desired display device
       --directx-wallpaper, --no-directx-wallpaper
       --directx-wallpaper, --no-directx-wallpaper
                                 Enable wallpaper mode  (default disabled)</nowiki>
                                 Enable wallpaper mode  (default disabled)
 
</nowiki>

Revision as of 18:08, 7 April 2005

As you may have noticed, the command vlc --help is not very useful due to to the non-scrollable pop-up window that opened.

If you look for help, on a particular module, use vlc -p module --advanced

So here the output of vlc --longhelp --advanced as of 7th April 2005 for the development version.

If you want extra explanations, you can try the --help-verbose option. Help verbose


     
Usage: c:\...\vlc-0.8.2-svn-20050407\vlc.exe [options] [playlistitems] ...
You can specify multiple playlistitems on the commandline. They will be enqueued in the playlist.
The first item specified will be played first.

Options-styles:
  --option  A global option that is set for the duration of the program.
   -option  A single letter version of a global --option.
   :option  An option that only applies to the playlistitem directly before it
            and that overrides previous settings.

Playlistitem MRL syntax:
  URL[@[title][:chapter][-[title][:chapter]]] [:option=value ...]

  Many of the global --options can also be used as MRL specific :options.
  Multiple :option=value pairs can be specified.

URL syntax:
  [file://]filename              Plain media file
  http://ip:port/file            HTTP URL
  ftp://ip:port/file             FTP URL
  mms://ip:port/file             MMS URL
  screen://                      Screen capture
  [dvd://][device][@raw_device]  DVD device
  [vcd://][device]               VCD device
  [cdda://][device]              Audio CD device
  udp:[[<source address>]@[<bind address>][:<bind port>]]
                                 UDP stream sent by a streaming server
  vlc:pause                      Special item to pause the playlist
  vlc:quit                       Special item to quit VLC

 Audio
      --audio, --noaudio         Enable audio (default enabled)
      --volume <integer>         Audio output volume
      --aout-rate <integer>      Audio output frequency (Hz)
      --hq-resampling, --no-hq-resampling
                                 High quality audio resampling (default
                                 enabled)
      --spdif, --nospdif         Use the S/PDIF audio output when available
                                 (default disabled)
      --audio-desync <integer>   Audio desynchronisation compensation
      --aout <string>            Audio output module
      --audio-filter <string>    Audio filters
      --audio-visual <string>    Audio visualizations 

 Video
      --video, --novideo         Enable video (default enabled)
      --grayscale, --nograyscale Greyscale video output (default disabled)
  -f, --fullscreen, --nofullscreen
                                 Fullscreen video output (default disabled)
      --skip-frames, --no-skip-frames
                                 Skip frames (default enabled)
      --quiet-synchro, --no-quiet-synchro
                                 Quiet synchro (default disabled)
      --overlay, --nooverlay     Overlay video output (default enabled)
      --video-on-top, --no-video-on-top
                                 Always on top (default disabled)
      --snapshot-path <string>   Video snapshot directory
      --snapshot-format {png,jpg}
                                 Video snapshot format
      --width <integer>          Video width
      --height <integer>         Video height
      --video-x <integer>        Video x coordinate
      --video-y <integer>        Video y coordinate
      --aspect-ratio <string>    Source aspect ratio
      --video-deco, --no-video-deco
                                 Window decorations (default enabled)
      --video-title <string>     Video title
      --align {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                 Video alignment
      --zoom <float>             Zoom video
  -V, --vout <string>            Video output module
      --vout-filter <string>     Video filter module

 Subpictures
      --osd, --noosd             On Screen Display (default enabled)
      --sub-file <string>        Use subtitle file
      --sub-autodetect-file, --no-sub-autodetect-file
                                 Autodetect subtitle files (default enabled)
      --sub-autodetect-fuzzy <integer>
                                 Subtitle autodetection fuzziness
      --sub-autodetect-path <string>
                                 Subtitle autodetection paths
      --sub-margin <integer>     Force subtitle position
      --sub-filter <string>      Subpictures filter module

 Input
      --access <string>          Access module
      --access-filter <string>   Access filter module
      --demux <string>           Demux module
      --program <integer>        Choose programme (SID)
      --programs <string>        Choose programs
      --audio-track <integer>    Choose audio track
      --sub-track <integer>      Choose subtitles track
      --audio-language <string>  Choose audio language
      --sub-language <string>    Choose subtitle language
      --input-repeat <integer>   Input repetitions
      --start-time <integer>     Input start time (seconds)
      --stop-time <integer>      Input stop time (seconds)
      --input-list <string>      Input list
      --input-slave <string>     Input slave (experimental)
      --bookmarks <string>       Bookmarks list for a stream
      --dvd <string>             DVD device
      --vcd <string>             VCD device
      --cd-audio <string>        Audio CD device
      --server-port <integer>    UDP port
      --mtu <integer>            MTU of the network interface
      --iface-addr <string>      Network interface address
  -6, --ipv6, --noipv6           Force IPv6 (default disabled)
  -4, --ipv4, --noipv4           Force IPv4 (default disabled)
      --socks <string>           SOCKS server
      --socks-user <string>      SOCKS user name
      --socks-pwd <string>       SOCKS password
      --meta-title <string>      Title metadata
      --meta-author <string>     Author metadata
      --meta-artist <string>     Artist metadata
      --meta-genre <string>      Genre metadata
      --meta-copyright <string>  Copyright metadata
      --meta-description <string>
                                 Description metadata
      --meta-date <string>       Date metadata
      --meta-url <string>        URL metadata
      --cr-average <integer>     Clock reference average counter
      --clock-synchro {-1 (Default), 0 (Disable), 1 (Enable)}
                                 Clock synchronisation

 Decoders
      --codec <string>           Preferred codecs list
      --encoder <string>         Preferred encoders list

 Stream output
      --sout <string>            Default stream output chain
      --sout-display, --no-sout-display
                                 Display while streaming (default disabled)
      --sout-keep, --no-sout-keep
                                 Keep stream output open (default disabled)
      --sout-all, --no-sout-all  Enable streaming of all ES (default disabled)
      --sout-audio, --no-sout-audio
                                 Enable audio stream output (default enabled)
      --sout-video, --no-sout-video
                                 Enable video stream output (default enabled)
      --ttl <integer>            Time to live
      --mux <string>             Mux module
      --access_output <string>   Access output module
      --packetizer <string>      Preferred packetiser list
      --sap-flow-control, --no-sap-flow-control
                                 Control SAP flow (default disabled)
      --sap-interval <integer>   SAP announcement interval

 CPU
      --fpu, --nofpu             Enable FPU support (default enabled)
      --mmx, --nommx             Enable CPU MMX support (default enabled)
      --3dn, --no3dn             Enable CPU 3D Now! support (default enabled)
      --mmxext, --nommxext       Enable CPU MMX EXT support (default enabled)
      --sse, --nosse             Enable CPU SSE support (default enabled)
      --sse2, --nosse2           Enable CPU SSE2 support (default enabled)

 Miscellaneous
      --memcpy <string>          Memory copy module
  -A, --audio-channel-mixer <string>
                                 Channel mixer
      --plugins-cache, --no-plugins-cache
                                 Use a plugins cache (default enabled)
      --plugin-path <string>     Modules search path
      --minimize-threads, --no-minimize-threads
                                 Minimise number of threads (default disabled)
      --one-instance, --no-one-instance
                                 Allow only one running instance (default
                                 disabled)
      --high-priority, --no-high-priority
                                 Increase the priority of the process (default
                                 disabled)
      --fast-mutex, --no-fast-mutex
                                 Fast mutex on NT/2K/XP (developers only)
                                 (default disabled)
      --win9x-cv-method <integer>
                                 Condition variables implementation for Win9x
                                 (developers only)
      --vlm-conf <string>        VLM configuration file

 Playlist
  -Z, --random, --norandom       Play files randomly forever (default enabled)
  -L, --loop, --noloop           Repeat all (default enabled)
  -R, --repeat, --norepeat       Repeat current item (default disabled)
      --play-and-stop, --no-play-and-stop
                                 Play and stop (default disabled)
  -S, --services-discovery <string>
                                 Services discovery modules

 Interface
  -I, --intf <string>            Interface module
      --extraintf <string>       Extra interface modules
  -v, --verbose <integer>        Verbosity (0,1,2)
  -q, --quiet, --noquiet         Be quiet (default disabled)
      --language {auto,en,en_GB,bn,da,de,el,es,fr,hi,hu,it,ja,my,ne,nl,no,pl,ps,pt_BR,ru,sv,tet,tl}
                                 Language
      --color, --nocolor         Colour messages (default disabled)
      --advanced, --noadvanced   Show advanced options (default enabled)
      --control <string>         Control interfaces

 Hot keys
      --key-fullscreen <integer> Fullscreen
      --key-play-pause <integer> Play/Pause
      --key-pause <integer>      Pause only
      --key-play <integer>       Play only
      --key-faster <integer>     Faster
      --key-slower <integer>     Slower
      --key-next <integer>       Next
      --key-prev <integer>       Previous
      --key-stop <integer>       Stop
      --key-position <integer>   Position
      --key-jump-10sec <integer> Jump 10 seconds backwards
      --key-jump+10sec <integer> Jump 10 seconds forward
      --key-jump-1min <integer>  Jump 1 minute backwards
      --key-jump+1min <integer>  Jump 1 minute forward
      --key-jump-5min <integer>  Jump 5 minutes backwards
      --key-jump+5min <integer>  Jump 5 minutes forward
      --key-nav-activate <integer>
                                 Activate
      --key-nav-up <integer>     Navigate up
      --key-nav-down <integer>   Navigate down
      --key-nav-left <integer>   Navigate left
      --key-nav-right <integer>  Navigate right
      --key-quit <integer>       Quit
      --key-vol-up <integer>     Volume up
      --key-vol-down <integer>   Volume down
      --key-vol-mute <integer>   Mute
      --key-subdelay-up <integer>
                                 Subtitle delay up
      --key-subdelay-down <integer>
                                 Subtitle delay down
      --key-audiodelay-up <integer>
                                 Audio delay up
      --key-audiodelay-down <integer>
                                 Audio delay down
      --key-audio-track <integer>
                                 Cycle audio track
      --key-subtitle-track <integer>
                                 Cycle subtitle track
      --key-intf-show <integer>  Show interface
      --key-snapshot <integer>   Take video snapshot
      --key-set-bookmark1 <integer>
                                 Set playlist bookmark 1
      --key-set-bookmark2 <integer>
                                 Set playlist bookmark 2
      --key-set-bookmark3 <integer>
                                 Set playlist bookmark 3
      --key-set-bookmark4 <integer>
                                 Set playlist bookmark 4
      --key-set-bookmark5 <integer>
                                 Set playlist bookmark 5
      --key-set-bookmark6 <integer>
                                 Set playlist bookmark 6
      --key-set-bookmark7 <integer>
                                 Set playlist bookmark 7
      --key-set-bookmark8 <integer>
                                 Set playlist bookmark 8
      --key-set-bookmark9 <integer>
                                 Set playlist bookmark 9
      --key-set-bookmark10 <integer>
                                 Set playlist bookmark 10
      --key-play-bookmark1 <integer>
                                 Play playlist bookmark 1
      --key-play-bookmark2 <integer>
                                 Play playlist bookmark 2
      --key-play-bookmark3 <integer>
                                 Play playlist bookmark 3
      --key-play-bookmark4 <integer>
                                 Play playlist bookmark 4
      --key-play-bookmark5 <integer>
                                 Play playlist bookmark 5
      --key-play-bookmark6 <integer>
                                 Play playlist bookmark 6
      --key-play-bookmark7 <integer>
                                 Play playlist bookmark 7
      --key-play-bookmark8 <integer>
                                 Play playlist bookmark 8
      --key-play-bookmark9 <integer>
                                 Play playlist bookmark 9
      --key-play-bookmark10 <integer>
                                 Play playlist bookmark 10
      --key-history-back <integer>
                                 Go back in browsing history
      --key-history-forward <integer>
                                 Go forward in browsing history

 Help options
  -h, --help                     print help for VLC (can be combined with
                                 --advanced)
  -H, --longhelp                 print help for VLC and all it's modules (can
                                 be combined with --advanced)
      --advanced                 print help for the advanced options
      --help-verbose             ask for extra verbosity when displaying help
  -l, --list                     print a list of available modules
  -p, --module <string>          print help on a specific module (can be
                                 combined with --advanced)
      --save-config              save the current command line options in the
                                 config
      --reset-config             reset the current config to the default values
      --config <string>          use alternate config file
      --reset-plugins-cache      resets the current plugins cache
      --version                  print version information

 live.com (RTSP/RTP/SDP) demuxer
      --rtsp-tcp, --no-rtsp-tcp  Use RTP over RTSP (TCP) (default disabled)
      --rtsp-caching <integer>   Caching value (ms)
      --rtsp-kasenna, --no-rtsp-kasenna
                                 Kasenna RTSP dialect (default disabled)

 TS muxer (libdvbpsi)
      --sout-ts-pid-video <integer>
                                 Video PID
      --sout-ts-pid-audio <integer>
                                 Audio PID
      --sout-ts-pid-spu <integer>
                                 SPU PID
      --sout-ts-pid-pmt <integer>
                                 PMT PID
      --sout-ts-tsid <integer>   TS ID
      --sout-ts-es-id-pid, --no-sout-ts-es-id-pid
                                 Set PID to id of ES (default disabled)
      --sout-ts-shaping <integer>
                                 Shaping delay (ms)
      --sout-ts-use-key-frames, --no-sout-ts-use-key-frames
                                 Use keyframes (default disabled)
      --sout-ts-pcr <integer>    PCR delay (ms)
      --sout-ts-bmin <integer>   Minimum B (deprecated)
      --sout-ts-bmax <integer>   Maximum B (deprecated)
      --sout-ts-dts-delay <integer>
                                 DTS delay (ms)
      --sout-ts-crypt-audio, --no-sout-ts-crypt-audio
                                 Crypt audio (default enabled)
      --sout-ts-csa-ck <string>  CSA Key

 Matroska stream demuxer
      --mkv-use-ordered-chapters, --no-mkv-use-ordered-chapters
                                 Ordered chapters (default enabled)
      --mkv-use-chapter-codec, --no-mkv-use-chapter-codec
                                 Chapter codecs (default enabled)
      --mkv-seek-percent, --no-mkv-seek-percent
                                 Seek based on percent not time (default
                                 disabled)
      --mkv-use-dummy, --no-mkv-use-dummy
                                 Dummy Elements (default disabled)

 Ffmpeg audio/video decoder/encoder ((MS)MPEG4,SVQ1,H263,WMV,WMA)
      --ffmpeg-dr, --no-ffmpeg-dr
                                 Direct rendering (default enabled)
      --ffmpeg-error-resilience <integer>
                                 Error resilience
      --ffmpeg-workaround-bugs <integer>
                                 Workaround bugs
      --ffmpeg-hurry-up, --no-ffmpeg-hurry-up
                                 Hurry up (default disabled)
      --ffmpeg-vismv <integer>   Visualise motion vectors
      --ffmpeg-lowres <integer>  Low resolution decoding
      --ffmpeg-pp-q <integer>    Post processing quality
      --ffmpeg-pp-name <string>  ffmpeg post processing filter chains
      --ffmpeg-debug <integer>   Debug mask
      --sout-ffmpeg-hq {rd,bits,simple}
                                 Quality level
      --sout-ffmpeg-keyint <integer>
                                 Ratio of key frames
      --sout-ffmpeg-bframes <integer>
                                 Ratio of B frames
      --sout-ffmpeg-hurry-up, --no-sout-ffmpeg-hurry-up
                                 Hurry up (default disabled)
      --sout-ffmpeg-interlace, --no-sout-ffmpeg-interlace
                                 Enable interlaced encoding (default disabled)
      --sout-ffmpeg-vt <integer> Video bitrate tolerance
      --sout-ffmpeg-pre-me, --no-sout-ffmpeg-pre-me
                                 Enable pre motion estimation (default
                                 disabled)
      --sout-ffmpeg-strict-rc, --no-sout-ffmpeg-strict-rc
                                 Enable strict rate control (default disabled)
      --sout-ffmpeg-rc-buffer-size <integer>
                                 Rate control buffer size
      --sout-ffmpeg-rc-buffer-aggressivity <float>
                                 Rate control buffer aggressiveness
      --sout-ffmpeg-i-quant-factor <float>
                                 I quantisation factor
      --sout-ffmpeg-noise-reduction <integer>
                                 Noise reduction
      --sout-ffmpeg-mpeg4-matrix, --no-sout-ffmpeg-mpeg4-matrix
                                 Enable MPEG4 quantisation matrix (default
                                 disabled)
      --sout-ffmpeg-qmin <integer>
                                 Minimum video quantiser scale
      --sout-ffmpeg-qmax <integer>
                                 Maximum video quantiser scale
      --sout-ffmpeg-trellis, --no-sout-ffmpeg-trellis
                                 Enable trellis quantisation (default disabled)
      --sout-ffmpeg-qscale <float>
                                 Use fixed video quantizer scale
      --sout-ffmpeg-strict <integer>
                                 Strict standard compliance

 MPEG2 video switcher stream output
      --sout-switcher-files <string>
                                 Files
      --sout-switcher-sizes <string>
                                 Sizes
      --sout-switcher-aspect-ratio <string>
                                 Aspect ratio
      --sout-switcher-port <integer>
                                 Command UDP port
      --sout-switcher-command <integer>
                                 Command
      --sout-switcher-gop <integer>
                                 GOP size
      --sout-switcher-qscale <integer>
                                 Quantizer scale

 ATSC A/52 (AC-3) audio decoder
      --a52-dynrng, --no-a52-dynrng
                                 A/52 dynamic range compression (default
                                 enabled)

 Standard filesystem directory input
      --recursive {none,collapse,expand}
                                 Subdirectory behaviour

 Fake input
      --fake-caching <integer>   Caching value in ms
      --fake-fps <float>         Framerate

 Standard filesystem file input
      --file-caching <integer>   Caching value in ms
      --file-cat <string>        Concatenate with additional files

 FTP input
      --ftp-caching <integer>    Caching value in ms
      --ftp-user <string>        FTP user name
      --ftp-pwd <string>         FTP password
      --ftp-account <string>     FTP account

 HTTP input
      --http-proxy <string>      HTTP proxy
      --http-caching <integer>   Caching value in ms
      --http-user <string>       HTTP user name
      --http-pwd <string>        HTTP password
      --http-user-agent <string> HTTP user agent
      --http-reconnect, --no-http-reconnect
                                 Auto re-connect (default disabled)
      --http-continuous, --no-http-continuous
                                 Continuous stream (default disabled)

 Microsoft Media Server (MMS) input
      --mms-caching <integer>    Caching value in ms
      --mms-all, --no-mms-all    Force selection of all streams (default
                                 disabled)
      --mms-maxbitrate <integer> Select maximum bitrate stream

 File stream output
      --sout-file-append, --no-sout-file-append
                                 Append to file (default disabled)

 HTTP stream output
      --sout-http-user <string>  Username
      --sout-http-pwd <string>   Password
      --sout-http-mime <string>  Mime
      --sout-http-cert <string>  Certificate file
      --sout-http-key <string>   Private key file
      --sout-http-ca <string>    Root CA file
      --sout-http-crl <string>   CRL file

 UDP stream output
      --sout-udp-caching <integer>
                                 Caching value (ms)
      --sout-udp-ttl <integer>   Time To Live
      --sout-udp-group <integer> Group packets
      --sout-udp-late <integer>  Late delay (ms)
      --sout-udp-raw, --no-sout-udp-raw
                                 Raw write (default disabled)

 SMB input
      --smb-caching <integer>    Caching value in ms
      --smb-user <string>        SMB user name
      --smb-pwd <string>         SMB password
      --smb-domain <string>      SMB domain

 TCP input
      --tcp-caching <integer>    Caching value in ms

 UDP/RTP input
      --udp-caching <integer>    Caching value in ms
      --udp-auto-mtu, --no-udp-auto-mtu
                                 Autodetection of MTU (default enabled)

 Image properties filter
      --contrast <float>         Image contrast (0-2)
      --brightness <float>       Image brightness (0-2)
      --hue <integer>            Image hue (0-360)
      --saturation <float>       Image saturation (0-3)
      --gamma <float>            Image gamma (0-10)

 File audio output
      --audiofile-format {u8,s8,u16,s16,u16_le,s16_le,u16_be,s16_be,fixed32,float32,spdif}
                                 Output format
      --audiofile-channels <integer>
                                 Output channels number
      --audiofile-file <string>  Output file
      --audiofile-wav, --no-audiofile-wav
                                 Add wave header (default enabled)

 AVI demuxer
      --avi-interleaved, --no-avi-interleaved
                                 Force interleaved method (default disabled)
      --avi-index, --no-avi-index
                                 Force index creation (default disabled)

 Audio CD input
      --cdda-caching <integer>   Caching value in ms

 Clone video filter
      --clone-count <integer>    Number of clones
      --clone-vout-list <string> List of video output modules

 Crop video filter
      --crop-geometry <string>   Crop geometry (pixels)
      --autocrop, --noautocrop   Automatic cropping (default disabled)

 Deinterlacing video filter
      --deinterlace-mode {discard,blend,mean,bob,linear}
                                 Deinterlace mode

 Filedump demuxer
      --demuxdump-file <string>  Filename of dump
      --demuxdump-append, --no-demuxdump-append
                                 Append (default disabled)

 Distort video filter
      --distort-mode {wave,ripple}
                                 Distort mode

 Dummy interface function
      --dummy-quiet, --no-dummy-quiet
                                 Do not open a DOS command box interface
                                 (default disabled)
      --dummy-save-es, --no-dummy-save-es
                                 Save raw codec data (default disabled)
      --dummy-chroma <string>    Dummy image chroma format

 DVDnav Input
      --dvdnav-angle <integer>   DVD angle
      --dvdnav-caching <integer> Caching value in ms
      --dvdnav-menu, --no-dvdnav-menu
                                 Start directly in menu (default enabled)

 DVDRead Input (DVD without menu support)
      --dvdread-angle <integer>  DVD angle
      --dvdread-caching <integer>
                                 Caching value in ms
      --dvdread-css-method {title,disc,key}
                                 Method used by libdvdcss for decryption

 Equalizer 10 bands
      --equalizer-preset {flat,classical,club,dance,fullbass,fullbasstreble,fulltreble,headphones,largehall,live,party,pop,reggae,rock,ska,soft,softrock,techno}
                                 Equalizer preset
      --equalizer-bands <string> Bands gain
      --equalizer-2pass, --no-equalizer-2pass
                                 Two pass (default disabled)
      --equalizer-preamp <float> Global gain

 Freetype2 font renderer
      --freetype-font <string>   Font
      --freetype-fontsize <integer>
                                 Font size in pixels
      --freetype-opacity <integer>
                                 Opacity, 0..255
      --freetype-color {0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                 Text Default Color
      --freetype-rel-fontsize {20 (Smaller), 18 (Small), 16 (Normal), 12 (Large), 6 (Larger)}
                                 Font size

 Mouse gestures control interface
      --gestures-threshold <integer>
                                 Motion threshold (10-100)
      --gestures-button {left,middle,right}
                                 Trigger button

 GnuTLS TLS encryption layer
      --dh-bits <integer>        Diffie-Hellman prime bits
      --tls-cache-expiration <integer>
                                 Expiration time for resumed TLS sessions
      --tls-cache-size <integer> Number of resumed TLS sessions

 Goom effect
      --goom-width <integer>     Goom display width
      --goom-height <integer>    Goom display height
      --goom-speed <integer>     Goom animation speed

 H264 video demuxer
      --h264-fps <float>         Frames per Second

 Headphone channel mixer with virtual spatialization effect
      --headphone-dim <integer>  Characteristic dimension

 Hotkeys management interface
      --bookmark1 <string>       Playlist bookmark 1
      --bookmark2 <string>       Playlist bookmark 2
      --bookmark3 <string>       Playlist bookmark 3
      --bookmark4 <string>       Playlist bookmark 4
      --bookmark5 <string>       Playlist bookmark 5
      --bookmark6 <string>       Playlist bookmark 6
      --bookmark7 <string>       Playlist bookmark 7
      --bookmark8 <string>       Playlist bookmark 8
      --bookmark9 <string>       Playlist bookmark 9
      --bookmark10 <string>      Playlist bookmark 10

 HTTP remote control interface
      --http-host <string>       Host address
      --http-src <string>        Source directory
      --http-intf-cert <string>  Certificate file
      --http-intf-key <string>   Private key file
      --http-intf-ca <string>    Root CA file
      --http-intf-crl <string>   CRL file

 Image video output
      --image-out-format {png}   Image format
      --image-out-ratio <integer>
                                 Recording ratio
      --image-out-prefix <string>
                                 Filename prefix

 IPv4 network abstraction layer
      --ipv4-timeout <integer>   TCP connection timeout in ms

 File logging
      --logfile <string>         Log filename
      --logmode {text,html}      Log format

 Logo video filter
      --logo-file <string>       Logo filename
      --logo-x <integer>         X coordinate of the logo
      --logo-y <integer>         Y coordinate of the logo
      --logo-transparency <integer>
                                 Transparency of the logo
      --logo-position {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                 Logo position

 Marquee display sub filter
      --marq-marquee <string>    Marquee text
      --marq-x <integer>         X offset, from left
      --marq-y <integer>         Y offset, from the top
      --marq-position <integer>  Marquee position
      --marq-opacity <integer>   Opacity
      --marq-color {-268435456 (Default), 0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                 Text Default Color
      --marq-size <integer>      Font size, pixels
      --marq-timeout <integer>   Marquee timeout

 JPEG camera demuxer
      --mjpeg-fps <float>        Frames per Second

 MOD demuxer (libmodplug)
      --mod-noisereduction, --no-mod-noisereduction
                                 Noise reduction (default enabled)
      --mod-reverb, --no-mod-reverb
                                 Reverb (default disabled)
      --mod-reverb-level <integer>
                                 Reverb level (0-100)
      --mod-reverb-delay <integer>
                                 Reverb delay (ms)
      --mod-megabass, --no-mod-megabass
                                 Mega bass (default disabled)
      --mod-megabass-level <integer>
                                 Mega bass level (0-100)
      --mod-megabass-range <integer>
                                 Mega bass cut off (Hz)
      --mod-surround, --no-mod-surround
                                 Surround (default disabled)
      --mod-surround-level <integer>
                                 Surround level (0-100)
      --mod-surround-delay <integer>
                                 Surround delay (ms)

 Mosaic video sub filter
      --mosaic-alpha <integer>   Alpha blending
      --mosaic-height <integer>  Height in pixels
      --mosaic-width <integer>   Width in pixels
      --mosaic-align {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                 Mosaic alignment
      --mosaic-xoffset <integer> Top left corner x coordinate
      --mosaic-yoffset <integer> Top left corner y coordinate
      --mosaic-vborder <integer> Vertical border width in pixels
      --mosaic-hborder <integer> Horizontal border width in pixels
      --mosaic-position {0 (auto), 1 (fixed)}
                                 Positioning method
      --mosaic-rows <integer>    Number of rows
      --mosaic-cols <integer>    Number of columns
      --mosaic-keep-aspect-ratio, --no-mosaic-keep-aspect-ratio
                                 Keep aspect ratio when resizing (default
                                 disabled)
      --mosaic-keep-picture, --no-mosaic-keep-picture
                                 Keep original size (default disabled)
      --mosaic-order <string>    Order as a comma separated list of
                                 picture-id(s)
      --mosaic-delay <integer>   Delay

 Motion blur filter
      --blur-factor <integer>    Blur factor (1-127)

 Motion detect video filter
      --motiondetect-history <integer>
                                 History parameter
      --motiondetect-description <string>
                                 Description file

 ASF muxer
      --sout-asf-title <string>  Title
      --sout-asf-author <string> Author
      --sout-asf-copyright <string>
                                 Copyright
      --sout-asf-comment <string>
                                 Comment
      --sout-asf-rating <string> Rating
      --sout-asf-packet-size <integer>
                                 Packet Size

 MP4/MOV muxer
      --sout-mp4-faststart, --no-sout-mp4-faststart
                                 Create "Fast start" files (default enabled)

 Multipart jpeg muxer
      --sout-mpjpeg-separator <string>
                                 Multipart separator string

 PS muxer
      --sout-ps-dts-delay <integer>
                                 DTS delay (ms)

 Network synchronisation
      --netsync-master, --no-netsync-master
                                 Act as master for network synchronisation
                                 (default disabled)
      --netsync-master-ip <string>
                                 Master client ip address

 Volume normalizer
      --norm-buff-size <integer> Number of audio buffers
      --norm-max-level <float>   Max level

 Windows Service interface
      --ntservice-install, --no-ntservice-install
                                 Install Windows Service (default disabled)
      --ntservice-uninstall, --no-ntservice-uninstall
                                 Uninstall Windows Service (default disabled)
      --ntservice-name <string>  Display name of the Service
      --ntservice-options <string>
                                 Configuration options
      --ntservice-extraintf <string>
                                 Extra interface modules

 OpenGL video output
      --opengl-cube-speed <float>
                                 OpenGL cube rotation speed
      --opengl-effect {none,cube,transparent-cube}
                                 Select effect

 VLC internal picture video output
      --picture-id <string>      ID
      --picture-width <integer>  Video width
      --picture-height <integer> Video height

 PORTAUDIO audio output
      --portaudio-device <integer>
                                 Output device

 Remote control interface
      --rc-show-pos, --no-rc-show-pos
                                 Show stream position (default disabled)
      --rc-fake-tty, --no-rc-fake-tty
                                 Fake TTY (default disabled)
      --rc-unix <string>         UNIX socket command input
      --rc-host <string>         TCP command input
      --rc-quiet, --no-rc-quiet  Do not open a DOS command box interface
                                 (default disabled)

 SAP announces
      --sap-addr <string>        SAP multicast address
      --sap-ipv4, --no-sap-ipv4  IPv4-SAP listening (default enabled)
      --sap-ipv6, --no-sap-ipv6  IPv6-SAP listening (default disabled)
      --sap-ipv6-scope <string>  IPv6 SAP scope
      --sap-timeout <integer>    SAP timeout (seconds)
      --sap-parse, --no-sap-parse
                                 Try to parse the SAP (default enabled)
      --sap-strict, --no-sap-strict
                                 SAP Strict mode (default disabled)
      --sap-cache, --no-sap-cache
                                 Use SAP cache (default disabled)

 Screen Input
      --screen-caching <integer> Caching value in ms
      --screen-fps <float>       Frame rate
      --screen-fragment-size <integer>
                                 Capture fragment size

 Interface showing control interface
      --showintf-threshold <integer>
                                 Threshold

 Skinnable Interface
      --skins2-last <string>     Last skin used
      --skins2-config <string>   Config of last used skin
      --skins2-transparency, --no-skins2-transparency
                                 Enable transparency effects (default disabled)

 stream_out_bridge
      --sout-bridge-out-id <integer>
                                 ID
      --sout-bridge-in-delay <integer>
                                 Delay
      --sout-bridge-in-id-offset <integer>
                                 ID Offset

 Display stream output
      --sout-display-audio, --no-sout-display-audio
                                 Enable audio (default enabled)
      --sout-display-video, --no-sout-display-video
                                 Enable video (default enabled)
      --sout-display-delay <integer>
                                 Delay

 Elementary stream output
      --sout-es-access <string>  Output access method
      --sout-es-access-audio <string>
                                 Audio output access method
      --sout-es-access-video <string>
                                 Video output access method
      --sout-es-mux <string>     Output muxer
      --sout-es-mux-audio <string>
                                 Audio output muxer
      --sout-es-mux-video <string>
                                 Video output muxer
      --sout-es-dst <string>     Output URL
      --sout-es-dst-audio <string>
                                 Audio output URL
      --sout-es-dst-video <string>
                                 Video output URL

 RTP stream output
      --sout-rtp-dst <string>    Destination
      --sout-rtp-sdp <string>    SDP
      --sout-rtp-mux <string>    Muxer
      --sout-rtp-name <string>   Session name
      --sout-rtp-description <string>
                                 Session description
      --sout-rtp-url <string>    Session URL
      --sout-rtp-email <string>  Session email
      --sout-rtp-port-audio <integer>
                                 Audio port
      --sout-rtp-port-video <integer>
                                 Video port
      --sout-rtp-port <integer>  Port
      --sout-rtp-ttl <integer>   Time to live

 Standard stream output
      --sout-standard-access <string>
                                 Output access method
      --sout-standard-mux <string>
                                 Output muxer
      --sout-standard-url <string>
                                 Output URL
      --sout-standard-sap, --no-sout-standard-sap
                                 SAP announcing (default disabled)
      --sout-standard-name <string>
                                 Session name
      --sout-standard-group <string>
                                 Session groupname
      --sout-standard-sap-ipv6, --no-sout-standard-sap-ipv6
                                 SAP IPv6 announcing (default disabled)
      --sout-standard-slp, --no-sout-standard-slp
                                 SLP announcing (default disabled)

 Transcode stream output
      --sout-transcode-venc <string>
                                 Video encoder
      --sout-transcode-vcodec <string>
                                 Destination video codec
      --sout-transcode-vb <integer>
                                 Video bitrate
      --sout-transcode-scale <float>
                                 Video scaling
      --sout-transcode-fps <float>
                                 Video frame-rate
      --sout-transcode-deinterlace, --no-sout-transcode-deinterlace
                                 Deinterlace video (default disabled)
      --sout-transcode-width <integer>
                                 Video width
      --sout-transcode-height <integer>
                                 Video height
      --sout-transcode-croptop <integer>
                                 Video crop top
      --sout-transcode-cropleft <integer>
                                 Video crop left
      --sout-transcode-cropbottom <integer>
                                 Video crop bottom
      --sout-transcode-cropright <integer>
                                 Video crop right
      --sout-transcode-aenc <string>
                                 Audio encoder
      --sout-transcode-acodec <string>
                                 Destination audio codec
      --sout-transcode-ab <integer>
                                 Audio bitrate
      --sout-transcode-channels <integer>
                                 Audio channels
      --sout-transcode-samplerate <integer>
                                 Audio sample rate
      --sout-transcode-audio-sync, --no-sout-transcode-audio-sync
                                 Synchronise on audio track (default disabled)
      --sout-transcode-senc <string>
                                 Subtitles encoder
      --sout-transcode-scodec <string>
                                 Destination subtitles codec
      --sout-transcode-soverlay, --no-sout-transcode-soverlay
                                 Destination subtitles codec (default disabled)
      --sout-transcode-sfilter <string>
                                 Subpictures filter
      --sout-transcode-threads <integer>
                                 Number of threads

 Text subtitles decoder
      --subsdec-align {0 (Center), 1 (Left), 2 (Right)}
                                 Subtitles justification
      --subsdec-encoding {System Default,ASCII,UTF-8,,ISO-8859-1,CP1252,MacRoman,MacIceland,ISO-8859-15,,ISO-8859-2,CP1250,MacCentralEurope,MacCroatian,MacRomania,,ISO-8859-5,CP1251,MacCyrillic,MacUkraine,KOI8-R,KOI8-U,KOI8-RU,,ISO-8859-6,CP1256,MacArabic,,ISO-8859-7,CP1253,MacGreek,,ISO-8859-8,CP1255,MacHebrew,,ISO-8859-9,CP1254,MacTurkish,,ISO-8859-13,CP1257,,ISO-2022-JP,ISO-2022-JP-1,ISO-2022-JP-2,EUC-JP,SHIFT_JIS,,ISO-2022-CN,ISO-2022-CN-EXT,EUC-CN,EUC-TW,BIG5,BIG5-HKSCS,,ISO-2022-KR,EUC-KR,,MacThai,KOI8-T,,ISO-8859-3,ISO-8859-4,ISO-8859-10,ISO-8859-14,ISO-8859-16,,CP850,CP862,CP866,CP874,CP932,CP949,CP950,CP1133,CP1258,,Macintosh,,UTF-7,UTF-16,UTF-16BE,UTF-16LE,UTF-32,UTF-32BE,UTF-32LE,C99,JAVA,UCS-2,UCS-2BE,UCS-2LE,UCS-4,UCS-4BE,UCS-4LE,,HZ,GBK,GB18030,JOHAB,ARMSCII-8,Georgian-Academy,Georgian-PS,TIS-620,MuleLao-1,VISCII,TCVN,HPROMAN8,NEXTSTEP}
                                 Subtitles text encoding

 Text subtitles demux
      --sub-fps <float>          Frames per second
      --sub-delay <integer>      Subtitles delay
      --sub-type {auto,microdvd,subrip,subviewer,ssa1,ssa2-4,vplayer,sami}
                                 Subtitles fileformat

 Philips OGT (SVCD subtitle) decoder
      --svcdsub-debug <integer>  If nonzero, this gives additional debug
                                 information.

 VLM remote control interface
      --telnet-port <integer>    Telnet Interface port
      --telnet-password <string> Telnet Interface password

 Theora video decoder
      --sout-theora-quality <integer>
                                 Encoding quality

 Time display sub filter
      --time-format <string>     Time format string (%Y%m%d %H%M%S)
      --time-x <integer>         X offset, from left
      --time-y <integer>         Y offset, from the top
      --time-position {0 (Center), 1 (Left), 2 (Right), 4 (Top), 8 (Bottom), 5 (Top-Left), 6 (Top-Right), 9 (Bottom-Left), 10 (Bottom-Right)}
                                 Time position
      --time-opacity <integer>   Opacity, 0..255
      --time-color {-268435456 (Default), 0 (Black), 8421504 (Gray), 12632256 (Silver), 16777215 (White), 8388608 (Maroon), 16711680 (Red), 16711935 (Fuchsia), 16776960 (Yellow), 8421376 (Olive), 32768 (Green), 32896 (Teal), 65280 (Lime), 8388736 (Purple), 128 (Navy), 255 (Blue), 65535 (Aqua)}
                                 Text Default Color
      --time-size <integer>      Font size, pixels

 Libtoolame audio encoder
      --sout-toolame-quality <float>
                                 Encoding quality
      --sout-toolame-mode <integer>
                                 Stereo mode
      --sout-toolame-vbr, --no-sout-toolame-vbr
                                 VBR mode (default disabled)

 Video transformation filter
      --transform-type {90,180,270,hflip,vflip}
                                 Transform type

 MPEG Transport Stream demuxer
      --ts-extra-pmt <string>    Extra PMT
      --ts-es-id-pid, --no-ts-es-id-pid
                                 Set id of ES to PID (default disabled)
      --ts-out <string>          Fast udp streaming
      --ts-out-mtu <integer>     MTU for out mode
      --ts-csa-ck <string>       CSA ck
      --ts-silent, --no-ts-silent
                                 Silent mode (default disabled)
      --ts-capmt-sysid <integer> CAPMT System ID

 VCD input
      --vcd-caching <integer>    Caching value in ms

 Visualizer filter
      --effect-list <string>     Effects list
      --effect-width <integer>   Video width
      --effect-height <integer>  Video height
      --visual-nbbands <integer> Number of bands
      --visual-separ <integer>   Band separator
      --visual-amp <integer>     Amplification
      --visual-peaks, --no-visual-peaks
                                 Enable peaks (default enabled)
      --visual-stars <integer>   Number of stars

 RTSP VoD server
      --rtsp-host <string>       Host address

 Vorbis audio decoder
      --sout-vorbis-quality <integer>
                                 Encoding quality
      --sout-vorbis-max-bitrate <integer>
                                 Maximum encoding bitrate
      --sout-vorbis-min-bitrate <integer>
                                 Minimum encoding bitrate
      --sout-vorbis-cbr, --no-sout-vorbis-cbr
                                 CBR encoding (default disabled)

 Wall video filter
      --wall-cols <integer>      Number of columns
      --wall-rows <integer>      Number of rows
      --wall-active <string>     Active windows
      --wall-element-aspect <string>
                                 Element aspect ratio

 Win32 waveOut extension output
      --waveout-float32, --no-waveout-float32
                                 Use float32 output (default enabled)

 wxWindows interface module
      --wxwin-embed, --no-wxwin-embed
                                 Embed video in interface (default enabled)
      --wxwin-bookmarks, --no-wxwin-bookmarks
                                 Show bookmarks dialogue (default disabled)
      --wxwin-taskbar, --no-wxwin-taskbar
                                 Show taskbar entry (default enabled)
      --wxwin-systray, --no-wxwin-systray
                                 Show systray icon (default disabled)
      --wxwin-config-last <string>
                                 last config

 DirectShow input
      --dshow-caching <integer>  Caching value in ms
      --dshow-vdev {,none}       Video device name
      --dshow-adev {,none}       Audio device name
      --dshow-size <string>      Video size
      --dshow-chroma <string>    Video input chroma format
      --dshow-config, --no-dshow-config
                                 Device properties (default disabled)
      --dshow-tuner, --no-dshow-tuner
                                 Tuner properties (default disabled)
      --dshow-tuner-channel <integer>
                                 Tuner TV Channel
      --dshow-tuner-country <integer>
                                 Tuner country code
      --dshow-tuner-input {0 (Default), 1 (Cable), 2 (Antenna)}
                                 Tuner input type

 DirectX video output
      --directx-hw-yuv, --no-directx-hw-yuv
                                 Use hardware YUV->RGB conversions (default
                                 enabled)
      --directx-use-sysmem, --no-directx-use-sysmem
                                 Use video buffers in system memory (default
                                 disabled)
      --directx-3buffering, --no-directx-3buffering
                                 Use triple buffering for overlays (default
                                 enabled)
      --directx-device {}        Name of desired display device
      --directx-wallpaper, --no-directx-wallpaper
                                 Enable wallpaper mode  (default disabled)